@@ -9,7 +9,7 @@ import pkg_resources
 
 
 def prinfPath():
-    print("!!!" + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml")
+    print(os.path.dirname(os.path.realpath(__file__)) + "\haarcascades\haarcascade_frontalface_default.xml")
 
 def prinfABC():
     print("ABC")
@@ -39,7 +39,6 @@ def faceRecognizer(filepath):
     # img = cv2.resize(img,(1920,1080),interpolation=cv2.INTER_CUBIC)
 
     parent = os.path.dirname(os.path.realpath(__file__))
-    print(parent+"haarcascades/haarcascade_frontalface_default.xml")
 
     # 转换成灰度图像
     gray_img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
@@ -49,31 +48,32 @@ def faceRecognizer(filepath):
         # "haarcascades/haarcascade_frontalface_default.xml"
         # "haarcascade_frontalface_default.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_default
-        parent+"haarcascades/haarcascade_frontalface_default.xml"
+        parent+"\haarcascades\haarcascade_frontalface_default.xml"
+
     )
     classifier_alt_tree = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt_tree.xml"
         # "haarcascade_frontalface_alt_tree.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt_tree
-        parent + "haarcascades/haarcascade_frontalface_alt_tree.xml"
+        parent + "\haarcascades\haarcascade_frontalface_alt_tree.xml"
     )
     classifier_alt2 = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt2.xml"
         # "haarcascade_frontalface_alt2.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt2
-        parent+"haarcascades/haarcascade_frontalface_alt2.xml"
+        parent+"\haarcascades\haarcascade_frontalface_alt2.xml"
     )
     classifier_alt = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt.xml"
         # "haarcascade_frontalface_alt.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_alt
-        parent + "haarcascades/haarcascade_frontalface_alt.xml"
+        parent + "\haarcascades\haarcascade_frontalface_alt.xml"
     )
     classifier_ce = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_profileface.xml"
         # "haarcascade_profileface.xml"
         # blurredface_sts_test.haarcascade.haarcascade_profileface
-        parent+"haarcascades/haarcascade_profileface.xml"
+        parent+"\haarcascades\haarcascade_profileface.xml"
     )
     color = (0, 0, 255)  # 定义绘制颜色
     # 调用识别人脸
